@@ -5,4 +5,4 @@ pychecker --only --limit 1000 \
 	--no-callinit --no-local --no-shadow --no-shadowbuiltin \
 	--no-import --no-miximport --no-pkgimport --no-reimport \
 	--no-argsused --no-varargsused --no-override \
-	fireinfo/*.py
+	src/fireinfo/*.py
